contexttools.TempoMark
======================

.. abjad-lineage:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark

.. autoclass:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.attach
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.detach
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.duration
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.duration_to_milliseconds
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.effective_context
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_imprecise
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_tempo_mark_token
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.lilypond_format
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.quarters_per_minute
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.start_component
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.storage_format
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.target_context
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.textual_indication
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.units_per_minute
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__add__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__call__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__copy__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__div__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__eq__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__mul__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__ne__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__repr__
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__sub__

Bases
-----

- :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

- :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_imprecise
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.quarters_per_minute
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.target_context
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.duration
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.textual_indication
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.units_per_minute
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.detach
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.duration_to_milliseconds
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_tempo_mark_token
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__add__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__copy__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__div__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__mul__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__sub__
   :noindex:
